/*********************************************
* Author: Eric Z. Ayers
* This program is to test the programming of the ATMEGA162 with an LED
*
* PIN 21  PC0          to LED  HIGH to turn on the LED
*
* Chip type           : AT MEGA 162
* Clock frequency     : 4.000000 MHz (external crystal)
*
*
*********************************************/

/*************************************************************************
 *			Macros
 *************************************************************************/


/* Set CPU frequency for libc routines and macros */
//#define F_CPU 1000000UL  // 1 MHz
//#define F_CPU 14.7456E6
#define F_CPU 4000000UL  // 4 MHz
//#define F_CPU 8000000UL  // 8 MHz (internal osc)

#ifndef sbi
#define sbi(_register,_bit_value) (_register) |= _BV(_bit_value)
#endif

#ifndef cbi
#define cbi(_register,_bit_value) (_register) &= ~(_BV(_bit_value))
#endif

/*************************************************************************
 *			Include Files
 *************************************************************************/

#include <io.h>
#include <avr/delay.h>
#include <avr/interrupt.h>
#include <avr/signal.h>

/*************************************************************************
 *			Static Data
 *************************************************************************/


/*************************************************************************
 *			Functions
 *************************************************************************/

/* Delay using the avr libc delay functions */
static void delay_ms (uint16_t ms)
{
	for (;ms>0;ms--)
		_delay_ms(1);
}


static void blink_n_times (int8_t n)
{
	while (n-- > 0)
	{
                /* set output to 5V, LED on */
                PORTC|= _BV(PC0);
                delay_ms(500);

                /* set output to GND, led off */
                PORTC&= ~_BV(PC0);
                delay_ms(500);
	}
}


int main(void)
{
	int i = 0;
	/* INITIALIZE */
	
	
	/* Enable PC0 as output
	 */
	DDRC |= _BV(PC0);

	/* Flash the led rapidly to show reset */
	while (i < 20)
	{
		/* off */
		PORTC &= ~_BV(PC0);
		delay_ms(50);
		/* on */
		PORTC |= _BV(PC0);
		delay_ms(5);
		i++;
	}

	/* Turn OFF the LED by setting PC0 low */
	PORTC &= ~_BV(PC0);	
	
	
	/* Loop forever */
	while (1)
	{
		delay_ms(1000);		

		for (i=0;i<8;i++)
		{
			blink_n_times(i);
			delay_ms(1000);
		}
	}
}

