/* From Embedded Systems article "PID without a PhD"
    http://www.embedded.com/2000/0010/0010feat3.htm
*/

/* PID State structure
 */
typedef struct
{
	double dState; 	// Last position input
	double iState;	// Integrator state
	double iMax;    // Maximum allowable integrator state
	double iMin;  	// Minimum allowable integrator state
	double iGain;  	// Integral gain
	double pGain;  	// Proportional gain
	double dGain; 	// Derivative gain
} SPid;


double UpdatePID(SPid * pid, double error, double position)

	double pTerm, dTerm, iTerm;
	
	// calculate the proportional term
	pTerm = calc_proportional (error);
	
	// calculate the integral state with appropriate limiting
	iTerm = calc_integral(pid, error);

	// Use the Differential term
	dTerm = calc_differential(pid, position)

	return pTerm + iTerm - dTerm;
}


/*
  From the article:
    A proportional controller is just the error signal multiplied by a
    constant and fed out to the drive. The proportional term gets
    calculated with the following code: 
*/

double calc_proportional (Spid *pid, double error)
{

  double pTerm;

  /* ... */
  
  pTerm = pid->pGain * error;
  
  /* ... */
  
  
  return pTerm;
}

/*
  	The integrator state, iState is the sum of all the preceding
  	inputs. The parameters iMin and iMax are the minimum and
  	maximum allowable integrator state values.
*/
double calc_integral (Spid *pid, double error)
{
	double iTerm;
	
	/* ... */
	
	// calculate the integral state 
	// with appropriate limiting
	pid->iState += error;
	if (pid->iState > pid->iMax)
	{
		pid->iState =
			pid->iMax;
	}
	else if (pid->iState < pid->iMin)
	{
		pid->iState = pid->iMin;
	}
	
	iTerm = pid->iGain * pid->iState;
	
	// calculate the integral term
	
	/* ... */
}  

static double calc_differential (Spid *pid, double position)
{
	double dTerm;

	/* ... */	

	dTerm = pid->dGain * (position - pid->dState);
	pid->dState = position;
	
  	/* ... */
}


int main ()
{
	/* ... */
	position = ReadPlantADC();
	drive = UpdatePID(&plantPID,   
			  plantCommand - position, 
			  position);
	DrivePlantDAC(drive);
	/* ... */	
}
