MCU=atmega162
GCCDIR  := /usr/local/gcc-avr-4.0.1/
CC 	:= $(GCCDIR)/bin/avr-gcc
OBJCOPY := $(GCCDIR)/bin/avr-objcopy
PORT    := /dev/ttyS0

BASE    := test_porta_pins

CFLAGS := -g -mmcu=$(MCU) -Wall -Wstrict-prototypes  -I$(GCCDIR)/avr/include -I$(GCCDIR)/avr/include/avr
LDFLAGS := -L$(GCCDIR)/avr/lib


all: $(BASE).hex

$(BASE).hex:	$(BASE).out
	$(OBJCOPY) -R .eeprom -O ihex $< $@ 
$(BASE).out:	$(BASE).o
	$(CC) $(CFLAGS) $(LDFLAGS) -o $@ -Wl,-Map,$(BASE).map $<

$(BASE).o:	$(BASE).c
	$(CC) $(CFLAGS) -Os -c $(BASE).c

load:	$(BASE).hex
	# Fuse bits of ATMEGA16 factory default
	#   Fuse Low Byte      = 0x62
	#   Fuse High Byte     = 0x99
	#   Fuse Extended Byte = 0xff
	#
	# Reconfigure fuse bits of ATMEGA162 for 4MHZ external crystal
	# Turn off the clock div/8 feature by setting bit 7 to 1
        # high nybble of low byte - 0b1010 = A
        # low nybble  of low byte - 0b1101 = D
	# Turn off JTAG to be able to use port C pins as digital i/o
        # high nybble of high byte - 0b1101 = D
        # low nybble  of low byte - 0b1001 = 9
	uisp -dserial=$(PORT) -dprog=avrisp -dpart=$(MCU) --wr_fuse_h=0xD9 --wr_fuse_l=0xAD 
	uisp -dserial=$(PORT) --erase --upload if=$(BASE).hex -dprog=avrisp -v=3 -dpart=$(MCU) 


clean:
	rm -f *.o *.map *.out






