/*********************************************
 * Test of port A pins. Sets the pins high one at a time.
 *
 * PORTA - LCD Data pins DB0-DB7
 *
 * Status LED on pin PC0
 *
 * Chip type           : ATMEGA162
 * Clock frequency     : 4.000000 MHz
 *********************************************/

/*************************************************************************
 *			Macros
 *************************************************************************/
/* Set CPU frequency for libc routines and macros */
#define F_CPU 4000000UL  // 4 MHz


#define STATUS_LED_ON 		PORTC |= _BV(PC0);
#define STATUS_LED_OFF 		PORTC &= ~(_BV(PC0));
/*************************************************************************
 *			Includes
 *************************************************************************/
#include <io.h>
#include <avr/delay.h>


/*************************************************************************
 *			Function Prototypes
 *************************************************************************/

static void delay_ms (uint16_t ms);
static void delay_us (int32_t us);
	
/*************************************************************************
 *			Functions
 *************************************************************************/


/*
  delay_ms
  --------
  Delay up to 2^16 milliseconds using the avr libc delay functions
*/
static void delay_ms (uint16_t ms)
{
	for (;ms>0;ms--)
		_delay_ms(1);
}


/*
  delay_us
  --------
  Delay up to 2^16 microseconds using the avr libc delay functions.
  Accurate to about 10 us.
*/
static void delay_us (int32_t us)
{
	for (;us>0;us--)
		_delay_us(1);
}

/*
  blink_n_times
  -------------
  Blink the status LED n times (rate is 4 Hz)
 */
static void blink_n_times (int8_t count)
{
	for (; count >=0;count--)
	{
                STATUS_LED_ON;
                delay_ms(100);
                STATUS_LED_OFF;
                delay_ms(150);
	}	
}

int main (int argc, char *argv[])
{
	int count;

	/* Debug LED set to PC0 */
	DDRC|= _BV(PC0);

	/* Turn OFF JTAG to be able to use pins pc4 & 5 for digital I/O */
	//MCUCSR |= _BV(JTD);

	/* flash rapidly to show reset */
	for (count = 0; count < 10; count++)
	{
		STATUS_LED_ON;
		delay_ms(25);
		STATUS_LED_OFF;
		delay_ms(75);
	}
	
	/* cycle through the pins 3-5 on portC to test them. */

	DDRC=0xFF;
	PORTC=0x00;

	while (1)	
	{
		for (count=3;count<6;count++)
		{
			PORTC=_BV(count);
			blink_n_times(count);
			delay_ms(5000);
		}	

	}

	
}
